==> ark-17.04.1.tar.xz: ark-17.04.1/plugins/libsinglefileplugin/kerfuffle_libgz.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the gzip algorithm",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «gzip»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «gzip»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem gzip",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο gzip",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo gzip",
        "Description[eu]": "Ireki eta erauzi gzip algoritmoarekin konprimatutako fitxategiak banaka",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo gzip",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het gzip-algoritme",
        "Description[pl]": "Otwieraj i wypakowuj pojedyncze pliki spakowane algorytmem gzip",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo Gzip",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom gzip",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom gzip",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом гзип",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom gzip",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom gzip",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом гзип",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med gzip-algoritmen",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму gzip",
        "Description[x-test]": "xxOpen and extract single files compressed with the gzip algorithmxx",
        "Description[zh_CN]": "打开和解压 gzip 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 gzip 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libgz",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Gzip plugin",
        "Name[ca@valencia]": "Connector del Gzip",
        "Name[ca]": "Connector del Gzip",
        "Name[cs]": "Modul pro gzip",
        "Name[de]": "Gzip-Modul",
        "Name[el]": "Πρόσθετο Gzip",
        "Name[es]": "Complemento Gzip",
        "Name[eu]": "Gzip plugina",
        "Name[it]": "Estensione Gzip",
        "Name[nl]": "Gzip-plug-in",
        "Name[pl]": "Wtyczka gzip",
        "Name[pt]": "'Plugin' do Gzip",
        "Name[sk]": "Plugin Gzip",
        "Name[sl]": "Vstavek Gzip",
        "Name[sr@ijekavian]": "Прикључак за гзип",
        "Name[sr@ijekavianlatin]": "Priključak za gzip",
        "Name[sr@latin]": "Priključak za gzip",
        "Name[sr]": "Прикључак за гзип",
        "Name[sv]": "Gzip-insticksprogram",
        "Name[uk]": "Додаток gzip",
        "Name[x-test]": "xxGzip pluginxx",
        "Name[zh_CN]": "Gzip 插件",
        "Name[zh_TW]": "Gzip 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Priority": 100
}

==> ark-17.04.2.tar.xz: ark-17.04.2/plugins/libsinglefileplugin/kerfuffle_libgz.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the gzip algorithm",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «gzip»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «gzip»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem gzip",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem GZip-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο gzip",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo gzip",
        "Description[eu]": "Ireki eta erauzi gzip algoritmoarekin konprimatutako fitxategiak banaka",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme gzip",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo gzip",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het gzip-algoritme",
        "Description[pl]": "Otwieraj i wypakowuj pojedyncze pliki spakowane algorytmem gzip",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo Gzip",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom gzip",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom gzip",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом гзип",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom gzip",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom gzip",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом гзип",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med gzip-algoritmen",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму gzip",
        "Description[x-test]": "xxOpen and extract single files compressed with the gzip algorithmxx",
        "Description[zh_CN]": "打开和解压 gzip 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 gzip 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libgz",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Gzip plugin",
        "Name[ca@valencia]": "Connector del Gzip",
        "Name[ca]": "Connector del Gzip",
        "Name[cs]": "Modul pro gzip",
        "Name[de]": "Gzip-Modul",
        "Name[el]": "Πρόσθετο Gzip",
        "Name[es]": "Complemento Gzip",
        "Name[eu]": "Gzip plugina",
        "Name[fr]": "Module externe d'archive « gzip »",
        "Name[it]": "Estensione Gzip",
        "Name[nl]": "Gzip-plug-in",
        "Name[pl]": "Wtyczka gzip",
        "Name[pt]": "'Plugin' do Gzip",
        "Name[sk]": "Plugin Gzip",
        "Name[sl]": "Vstavek Gzip",
        "Name[sr@ijekavian]": "Прикључак за гзип",
        "Name[sr@ijekavianlatin]": "Priključak za gzip",
        "Name[sr@latin]": "Priključak za gzip",
        "Name[sr]": "Прикључак за гзип",
        "Name[sv]": "Gzip-insticksprogram",
        "Name[uk]": "Додаток gzip",
        "Name[x-test]": "xxGzip pluginxx",
        "Name[zh_CN]": "Gzip 插件",
        "Name[zh_TW]": "Gzip 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Priority": 100
}
